@@ -29,12 +29,12 @@ __all__ = (
     "ActionTargetTypeDef",
     "ActionTypeDef",
     "CreateExperimentTemplateActionInputTypeDef",
-    "CreateExperimentTemplateRequestTypeDef",
-    "CreateExperimentTemplateResponseResponseTypeDef",
+    "CreateExperimentTemplateRequestRequestTypeDef",
+    "CreateExperimentTemplateResponseTypeDef",
     "CreateExperimentTemplateStopConditionInputTypeDef",
     "CreateExperimentTemplateTargetInputTypeDef",
-    "DeleteExperimentTemplateRequestTypeDef",
-    "DeleteExperimentTemplateResponseResponseTypeDef",
+    "DeleteExperimentTemplateRequestRequestTypeDef",
+    "DeleteExperimentTemplateResponseTypeDef",
     "ExperimentActionStateTypeDef",
     "ExperimentActionTypeDef",
     "ExperimentStateTypeDef",
@@ -50,30 +50,30 @@ __all__ = (
     "ExperimentTemplateTargetTypeDef",
     "ExperimentTemplateTypeDef",
     "ExperimentTypeDef",
-    "GetActionRequestTypeDef",
-    "GetActionResponseResponseTypeDef",
-    "GetExperimentRequestTypeDef",
-    "GetExperimentResponseResponseTypeDef",
-    "GetExperimentTemplateRequestTypeDef",
-    "GetExperimentTemplateResponseResponseTypeDef",
-    "ListActionsRequestTypeDef",
-    "ListActionsResponseResponseTypeDef",
-    "ListExperimentTemplatesRequestTypeDef",
-    "ListExperimentTemplatesResponseResponseTypeDef",
-    "ListExperimentsRequestTypeDef",
-    "ListExperimentsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "GetActionRequestRequestTypeDef",
+    "GetActionResponseTypeDef",
+    "GetExperimentRequestRequestTypeDef",
+    "GetExperimentResponseTypeDef",
+    "GetExperimentTemplateRequestRequestTypeDef",
+    "GetExperimentTemplateResponseTypeDef",
+    "ListActionsRequestRequestTypeDef",
+    "ListActionsResponseTypeDef",
+    "ListExperimentTemplatesRequestRequestTypeDef",
+    "ListExperimentTemplatesResponseTypeDef",
+    "ListExperimentsRequestRequestTypeDef",
+    "ListExperimentsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "ResponseMetadataTypeDef",
-    "StartExperimentRequestTypeDef",
-    "StartExperimentResponseResponseTypeDef",
-    "StopExperimentRequestTypeDef",
-    "StopExperimentResponseResponseTypeDef",
-    "TagResourceRequestTypeDef",
-    "UntagResourceRequestTypeDef",
+    "StartExperimentRequestRequestTypeDef",
+    "StartExperimentResponseTypeDef",
+    "StopExperimentRequestRequestTypeDef",
+    "StopExperimentResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "UpdateExperimentTemplateActionInputItemTypeDef",
-    "UpdateExperimentTemplateRequestTypeDef",
-    "UpdateExperimentTemplateResponseResponseTypeDef",
+    "UpdateExperimentTemplateRequestRequestTypeDef",
+    "UpdateExperimentTemplateResponseTypeDef",
     "UpdateExperimentTemplateStopConditionInputTypeDef",
     "UpdateExperimentTemplateTargetInputTypeDef",
 )
@@ -143,8 +143,8 @@ class CreateExperimentTemplateActionInputTypeDef(
     pass
 
 
-_RequiredCreateExperimentTemplateRequestTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateRequestTypeDef",
+_RequiredCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateExperimentTemplateRequestRequestTypeDef",
     {
         "clientToken": str,
         "description": str,
@@ -153,8 +153,8 @@ _RequiredCreateExperimentTemplateRequestTypeDef = TypedDict(
         "roleArn": str,
     },
 )
-_OptionalCreateExperimentTemplateRequestTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateRequestTypeDef",
+_OptionalCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateExperimentTemplateRequestRequestTypeDef",
     {
         "targets": Dict[str, "CreateExperimentTemplateTargetInputTypeDef"],
         "tags": Dict[str, str],
@@ -163,14 +163,15 @@ _OptionalCreateExperimentTemplateRequestTypeDef = TypedDict(
 )
 
 
-class CreateExperimentTemplateRequestTypeDef(
-    _RequiredCreateExperimentTemplateRequestTypeDef, _OptionalCreateExperimentTemplateRequestTypeDef
+class CreateExperimentTemplateRequestRequestTypeDef(
+    _RequiredCreateExperimentTemplateRequestRequestTypeDef,
+    _OptionalCreateExperimentTemplateRequestRequestTypeDef,
 ):
     pass
 
 
-CreateExperimentTemplateResponseResponseTypeDef = TypedDict(
-    "CreateExperimentTemplateResponseResponseTypeDef",
+CreateExperimentTemplateResponseTypeDef = TypedDict(
+    "CreateExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": "ExperimentTemplateTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -224,15 +225,15 @@ class CreateExperimentTemplateTargetInputTypeDef(
     pass
 
 
-DeleteExperimentTemplateRequestTypeDef = TypedDict(
-    "DeleteExperimentTemplateRequestTypeDef",
+DeleteExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "DeleteExperimentTemplateRequestRequestTypeDef",
     {
         "id": str,
     },
 )
 
-DeleteExperimentTemplateResponseResponseTypeDef = TypedDict(
-    "DeleteExperimentTemplateResponseResponseTypeDef",
+DeleteExperimentTemplateResponseTypeDef = TypedDict(
+    "DeleteExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": "ExperimentTemplateTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -408,53 +409,53 @@ ExperimentTypeDef = TypedDict(
     total=False,
 )
 
-GetActionRequestTypeDef = TypedDict(
-    "GetActionRequestTypeDef",
+GetActionRequestRequestTypeDef = TypedDict(
+    "GetActionRequestRequestTypeDef",
     {
         "id": str,
     },
 )
 
-GetActionResponseResponseTypeDef = TypedDict(
-    "GetActionResponseResponseTypeDef",
+GetActionResponseTypeDef = TypedDict(
+    "GetActionResponseTypeDef",
     {
         "action": "ActionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetExperimentRequestTypeDef = TypedDict(
-    "GetExperimentRequestTypeDef",
+GetExperimentRequestRequestTypeDef = TypedDict(
+    "GetExperimentRequestRequestTypeDef",
     {
         "id": str,
     },
 )
 
-GetExperimentResponseResponseTypeDef = TypedDict(
-    "GetExperimentResponseResponseTypeDef",
+GetExperimentResponseTypeDef = TypedDict(
+    "GetExperimentResponseTypeDef",
     {
         "experiment": "ExperimentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetExperimentTemplateRequestTypeDef = TypedDict(
-    "GetExperimentTemplateRequestTypeDef",
+GetExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "GetExperimentTemplateRequestRequestTypeDef",
     {
         "id": str,
     },
 )
 
-GetExperimentTemplateResponseResponseTypeDef = TypedDict(
-    "GetExperimentTemplateResponseResponseTypeDef",
+GetExperimentTemplateResponseTypeDef = TypedDict(
+    "GetExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": "ExperimentTemplateTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-ListActionsRequestTypeDef = TypedDict(
-    "ListActionsRequestTypeDef",
+ListActionsRequestRequestTypeDef = TypedDict(
+    "ListActionsRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -462,8 +463,8 @@ ListActionsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListActionsResponseResponseTypeDef = TypedDict(
-    "ListActionsResponseResponseTypeDef",
+ListActionsResponseTypeDef = TypedDict(
+    "ListActionsResponseTypeDef",
     {
         "actions": List["ActionSummaryTypeDef"],
         "nextToken": str,
@@ -471,8 +472,8 @@ ListActionsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListExperimentTemplatesRequestTypeDef = TypedDict(
-    "ListExperimentTemplatesRequestTypeDef",
+ListExperimentTemplatesRequestRequestTypeDef = TypedDict(
+    "ListExperimentTemplatesRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -480,8 +481,8 @@ ListExperimentTemplatesRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListExperimentTemplatesResponseResponseTypeDef = TypedDict(
-    "ListExperimentTemplatesResponseResponseTypeDef",
+ListExperimentTemplatesResponseTypeDef = TypedDict(
+    "ListExperimentTemplatesResponseTypeDef",
     {
         "experimentTemplates": List["ExperimentTemplateSummaryTypeDef"],
         "nextToken": str,
@@ -489,8 +490,8 @@ ListExperimentTemplatesResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListExperimentsRequestTypeDef = TypedDict(
-    "ListExperimentsRequestTypeDef",
+ListExperimentsRequestRequestTypeDef = TypedDict(
+    "ListExperimentsRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -498,8 +499,8 @@ ListExperimentsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListExperimentsResponseResponseTypeDef = TypedDict(
-    "ListExperimentsResponseResponseTypeDef",
+ListExperimentsResponseTypeDef = TypedDict(
+    "ListExperimentsResponseTypeDef",
     {
         "experiments": List["ExperimentSummaryTypeDef"],
         "nextToken": str,
@@ -507,15 +508,15 @@ ListExperimentsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -533,15 +534,15 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredStartExperimentRequestTypeDef = TypedDict(
-    "_RequiredStartExperimentRequestTypeDef",
+_RequiredStartExperimentRequestRequestTypeDef = TypedDict(
+    "_RequiredStartExperimentRequestRequestTypeDef",
     {
         "clientToken": str,
         "experimentTemplateId": str,
     },
 )
-_OptionalStartExperimentRequestTypeDef = TypedDict(
-    "_OptionalStartExperimentRequestTypeDef",
+_OptionalStartExperimentRequestRequestTypeDef = TypedDict(
+    "_OptionalStartExperimentRequestRequestTypeDef",
     {
         "tags": Dict[str, str],
     },
@@ -549,51 +550,51 @@ _OptionalStartExperimentRequestTypeDef = TypedDict(
 )
 
 
-class StartExperimentRequestTypeDef(
-    _RequiredStartExperimentRequestTypeDef, _OptionalStartExperimentRequestTypeDef
+class StartExperimentRequestRequestTypeDef(
+    _RequiredStartExperimentRequestRequestTypeDef, _OptionalStartExperimentRequestRequestTypeDef
 ):
     pass
 
 
-StartExperimentResponseResponseTypeDef = TypedDict(
-    "StartExperimentResponseResponseTypeDef",
+StartExperimentResponseTypeDef = TypedDict(
+    "StartExperimentResponseTypeDef",
     {
         "experiment": "ExperimentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-StopExperimentRequestTypeDef = TypedDict(
-    "StopExperimentRequestTypeDef",
+StopExperimentRequestRequestTypeDef = TypedDict(
+    "StopExperimentRequestRequestTypeDef",
     {
         "id": str,
     },
 )
 
-StopExperimentResponseResponseTypeDef = TypedDict(
-    "StopExperimentResponseResponseTypeDef",
+StopExperimentResponseTypeDef = TypedDict(
+    "StopExperimentResponseTypeDef",
     {
         "experiment": "ExperimentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tags": Dict[str, str],
     },
 )
 
-_RequiredUntagResourceRequestTypeDef = TypedDict(
-    "_RequiredUntagResourceRequestTypeDef",
+_RequiredUntagResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredUntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
     },
 )
-_OptionalUntagResourceRequestTypeDef = TypedDict(
-    "_OptionalUntagResourceRequestTypeDef",
+_OptionalUntagResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalUntagResourceRequestRequestTypeDef",
     {
         "tagKeys": List[str],
     },
@@ -601,8 +602,8 @@ _OptionalUntagResourceRequestTypeDef = TypedDict(
 )
 
 
-class UntagResourceRequestTypeDef(
-    _RequiredUntagResourceRequestTypeDef, _OptionalUntagResourceRequestTypeDef
+class UntagResourceRequestRequestTypeDef(
+    _RequiredUntagResourceRequestRequestTypeDef, _OptionalUntagResourceRequestRequestTypeDef
 ):
     pass
 
@@ -619,14 +620,14 @@ UpdateExperimentTemplateActionInputItemTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredUpdateExperimentTemplateRequestTypeDef = TypedDict(
-    "_RequiredUpdateExperimentTemplateRequestTypeDef",
+_RequiredUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateExperimentTemplateRequestRequestTypeDef",
     {
         "id": str,
     },
 )
-_OptionalUpdateExperimentTemplateRequestTypeDef = TypedDict(
-    "_OptionalUpdateExperimentTemplateRequestTypeDef",
+_OptionalUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateExperimentTemplateRequestRequestTypeDef",
     {
         "description": str,
         "stopConditions": List["UpdateExperimentTemplateStopConditionInputTypeDef"],
@@ -638,14 +639,15 @@ _OptionalUpdateExperimentTemplateRequestTypeDef = TypedDict(
 )
 
 
-class UpdateExperimentTemplateRequestTypeDef(
-    _RequiredUpdateExperimentTemplateRequestTypeDef, _OptionalUpdateExperimentTemplateRequestTypeDef
+class UpdateExperimentTemplateRequestRequestTypeDef(
+    _RequiredUpdateExperimentTemplateRequestRequestTypeDef,
+    _OptionalUpdateExperimentTemplateRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateExperimentTemplateResponseResponseTypeDef = TypedDict(
-    "UpdateExperimentTemplateResponseResponseTypeDef",
+UpdateExperimentTemplateResponseTypeDef = TypedDict(
+    "UpdateExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": "ExperimentTemplateTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
